/*
 * ClutterCairo.
 *
 * An simple Clutter Cairo 'Drawable'.
 *
 * Authored By Matthew Allum  <mallum@openedhand.com>
 *
 * Copyright (C) 2006 OpenedHand
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __CLUTTER_CAIRO_H__
#define __CLUTTER_CAIRO_H__

#include <glib-object.h>
#include <clutter/clutter-texture.h>
#include <cairo.h>

/**
 * SECTION:clutter-cairo
 * @short_description: Actor for displaying 
 *
 * #ClutterCairo is a #ClutterTexture that displays the contents
 * of a Cairo context.
 *
 * #ClutterCairo will provide a #cairo_t context by using the
 * clutter_cairo_create() and clutter_cairo_create_region() functions; you
 * can use the Cairo API to draw on the context.
 *
 * As soon as the context is destroyed with cairo_destroy(), the contents
 * of the context will be uploaded into the #ClutterCairo actor.
 *
 * |[
 *   cairo_t *cr;
 *
 *   cr = clutter_cairo_create (CLUTTER_CAIRO (texture));
 *
 *   /&ast; draw on the context &ast;/
 *
 *   cairo_destroy (cr);
 * ]|
 */

G_BEGIN_DECLS

#define CLUTTER_TYPE_CAIRO              (clutter_cairo_get_type ())
#define CLUTTER_CAIRO(obj)              (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLUTTER_TYPE_CAIRO, ClutterCairo))
#define CLUTTER_CAIRO_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), CLUTTER_TYPE_CAIRO, ClutterCairoClass))
#define CLUTTER_IS_CAIRO(obj)           (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLUTTER_TYPE_CAIRO))
#define CLUTTER_IS_CAIRO_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), CLUTTER_TYPE_CAIRO))
#define CLUTTER_CAIRO_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), CLUTTER_TYPE_CAIRO, ClutterCairoClass))

typedef struct _ClutterCairo            ClutterCairo;
typedef struct _ClutterCairoClass       ClutterCairoClass;
typedef struct _ClutterCairoPrivate     ClutterCairoPrivate;

struct _ClutterCairo
{
  /*< private >*/
  ClutterTexture         parent;

  ClutterCairoPrivate   *priv;
};

struct _ClutterCairoClass 
{
  /*< private >*/
  ClutterTextureClass parent_class;

  void (*_clutter_cairo_1) (void);
  void (*_clutter_cairo_2) (void);
  void (*_clutter_cairo_3) (void);
  void (*_clutter_cairo_4) (void);
}; 

GType         clutter_cairo_get_type       (void) G_GNUC_CONST;

/**
 * clutter_cairo_new:
 * @width: the width of the surface
 * @height: the height of the surface
 *
 * Creates a new #ClutterCairo actor, with a surface of @width by
 * @height pixels.
 *
 * Return value: the newly created #ClutterCairo actor
 */
ClutterActor *clutter_cairo_new            (guint         width,
                                            guint         height);

/**
 * clutter_cairo_create_region:
 * @cairo: a #ClutterCairo
 * @x_offset: offset of the region on the X axis
 * @y_offset: offset of the region on the Y axis
 * @width: width of the region
 * @height: height of the region
 *
 * Creates a new Cairo context that will updat the region defined
 * by @x_offset, @y_offset, @width and @height.
 *
 * Return value: a newly created Cairo context. Use cairo_destroy()
 *   to upload the contents of the context when done drawing.
 */
cairo_t *     clutter_cairo_create_region  (ClutterCairo *cairo,
                                            gint          x_offset,
                                            gint          y_offset,
                                            guint         width,
                                            guint         height);

/**
 * clutter_cairo_create:
 * @cairo: a #ClutterCairo
 *
 * Creates a new Cairo context for the @cairo texture. It is
 * similar to using clutter_cairo_create_region() with @x_offset
 * and @y_offset of 0, @width equals to the @cairo texture
 * surface width and @height equals to the @cairo texture surface
 * height.
 *
 * Return value: a newly created Cairo context. Use cairo_destroy()
 *   to upload the contents of the context when done drawing.
 */
cairo_t *     clutter_cairo_create         (ClutterCairo *cairo);

/**
 * clutter_cairo_surface_resize:
 * @cairo: a #ClutterCairo
 * @width: the new width of the surface
 * @height: the new height of the surface
 *
 * Resizes the Cairo surface used by @cairo to @width and @height.
 */
void          clutter_cairo_surface_resize (ClutterCairo *cairo,
                                            guint         width,
                                            guint         height);


/**
 * clutter_cairo_set_source_color:
 * @cr: a Cairo context
 * @color: a #ClutterColor
 *
 * Utility function for setting the source color of @cr using
 * a #ClutterColor.
 */
void          clutter_cairo_set_source_color (cairo_t            *cr,
                                              const ClutterColor *color);

G_END_DECLS

#endif /* __CLUTTER_CAIRO_H__ */
